Django email support
====================

Simple email support over django admin

Installation
------------


  $ pip install django_emailsupport


License: MIT
------------
© 2015 Martin Voldrich <rbas.cz@gmail.com>